Revert "[Scudo] enabling anonymous named pages on Linux 5.17 and onwards." am: b35c52a7fd am: 9821445c26 am: fecd9f13ba am: 8efb27c704 am: 3eaafcb476

Original change: https://android-review.googlesource.com/c/platform/external/scudo/+/2066959

Change-Id: Id65a4586074a2e0e2e5c3062e25855a5bf86ba14
Signed-off-by: Automerger Merge Worker <android-build-automerger-merge-worker@system.gserviceaccount.com>
diff --git a/standalone/linux.cpp b/standalone/linux.cpp
index 88875c5..c77c1bb 100644
--- a/standalone/linux.cpp
+++ b/standalone/linux.cpp
@@ -28,11 +28,11 @@
 #include <time.h>
 #include <unistd.h>
 
+#if SCUDO_ANDROID
 #include <sys/prctl.h>
 // Definitions of prctl arguments to set a vma name in kernels (Linux from 5.17).
 #ifndef PR_SET_VMA
 #define PR_SET_VMA 0x53564d41
 #define PR_SET_VMA_ANON_NAME 0
 #endif
 
 namespace scudo {
@@ -66,8 +66,10 @@
       dieOnMapUnmapError(errno == ENOMEM ? Size : 0);
     return nullptr;
   }
+#if SCUDO_ANDROID
   if (Name)
-    prctl(PR_SET_VMA, PR_SET_VMA_ANON_NAME, P, Size, Name);
+    prctl(ANDROID_PR_SET_VMA, ANDROID_PR_SET_VMA_ANON_NAME, P, Size, Name);
+#endif
   return P;
 }
@@ -28,11 +28,11 @@
 #include <sys/prctl.h>
-// Definitions of prctl arguments to set a vma name in kernels (Linux from 5.17).
-#ifndef PR_SET_VMA
-#define PR_SET_VMA 0x53564d41
-#define PR_SET_VMA_ANON_NAME 0
+// Definitions of prctl arguments to set a vma name in Android kernels.
+#define ANDROID_PR_SET_VMA 0x53564d41
+#define ANDROID_PR_SET_VMA_ANON_NAME 0
 #endif
 